function [MainFigure,h]=HRVAS_GUI()
  figH=750;   //height of GUI (pixels)
  figW=1000;  //width of GUI (pixels)
  ctlHpx=20;  //height wanted for controls (pixels)
  ctlWpx=45;  //width wanted for controls (pixels)

  colors.back=[0.8 0.8 0.8];
  colors.hist.face=[.5 .5 .9]; //histogram colors
  colors.hist.edge=[0 0 0];
  colors.vlf=[.5 .5 1];
  colors.lf=[.7 .5 1];//[.7 .6 1];//[1 1 .5];
  colors.hf=[.5 1 1];
  colors.waterfall.face=[.9 .9 .9];
  colors.status.back=[1 1 .4]; colors.status.face=[1 .4 .4];
  colors.white=[1 1 1]

 
  h=[];   //gui handles


  //// GUI: Main Figure
  
  //Main Figure
  MainFigure = figure('Position',[20 50 figW figH], ...
                      'CloseRequestFcn',"closeGUI",...
                      "figure_name","HRVAS",...
                      "icon",CWApath()+"icons/hrvas_icon.png",...
                      "color_map",jetcolormap(128),...
                      "backgroundcolor",[0.8 0.8 0.8],...
                      "dockable","off",...
                      "toolbar","none",...
                      "menubar","none",...
                      "default_axes","off",...
                      "visible","off");
  //delmenu(MainFigure.figure_id,gettext("&File"));
  //delmenu(MainFigure.figure_id, gettext("&Edit"));
  //delmenu(MainFigure.figure_id, gettext("&?"));
  
  //File Menu
  h.menuFile = uimenu('Label',_("File"),'Parent',MainFigure);
  uimenu(h.menuFile,'Label','Load IBI','Callback',"loadIBI_Callback");
  uimenu(h.menuFile,'Label','Load Settings','Callback',"loadSet_Callback");
  uimenu(h.menuFile,'Label','Save Settings','Callback',"saveSet_Callback");
  h.menuExport=uimenu(h.menuFile,'Label','Export HRV Results',...
                      'enable','off',...
                      'Callback',"menu_exportHRV");
  h.menuSave=uimenu(h.menuFile,'Label','Save All',...
                     'enable','off',...
                    'Callback',"menu_saveAll");
  uimenu(h.menuFile,'Label','Load All','Callback',"menu_loadAll");
  

  h.menuRun = uimenu('Label',_("Run"),'Parent',MainFigure,...
                     'enable','off',...
                     'Callback',"btnRun_Callback");


  h.menuHelp = uimenu('Label','Help','Parent',MainFigure);
  uimenu(h.menuHelp,'Label','About','Callback',"showAbout");
 
  ////  GUI: Preview
  //Controls---------------------------------------------------------
  //export button
 
  //preview IBI panel
  h.panelIBI=uipanel('Parent',MainFigure,...
                     'Units', 'normalized', ...
                     'Position',[0 1-0.3 1 .3]); 

  //axes handle    
  h.axesIBI = newaxes( h.panelIBI);
  h.axesIBI.axes_visible='on';
  h.axesIBI.margins=zeros(4,1);
  h.axesIBI.axes_bounds=[0.06 0.06 0.91 0.69]
  h.axesIBI.box="on";
  h.axesIBI.mark_size_unit="point";
  h.axesIBI.tight_limits="on";
  xlabel(h.axesIBI,'Time (hh:mm:ss)'); ylabel(h.axesIBI,'IBI (s)');
  h.f1=uicontrol('Parent',MainFigure,'style','frame','Units', 'normalized',...
               'Position',[0.002,0.965,0.02,0.03],'BackgroundColor',colors.back); 
  h.b=uicontrol(h.f1,'Style','pushbutton', 'String','^', 'Units','normalized',...
              'Position',[0 0 1 1],"callback","graph_open(""axesIBI"")");

  
  //// GUI: Analysis Options---------------------------------------------------------

  //Options panel
  h.panelOptions = uipanel('Parent',MainFigure,...
                           'Units', 'normalized', 'Position',[0 0 .5 .7],...
                           'BackgroundColor',colors.back);            
  h.lblHRV=uicontrol(h.panelOptions,'Style','text', ...
                     'String','HRV Analysis Options',...
                     'Units', 'normalized', 'Position',[0.01 .94 1-0.02 .05],...
                     'FontSize',12,...
                     'BackgroundColor',colors.back,...
                     'HorizontalAlignment','center');
  
  //// GUI: Analysis Options - Preprocessing------------------------------------------   
  h.panelPre = uipanel('Parent',h.panelOptions,"Title",'IBI Preprocessing',...
                       'Units', 'normalized', 'Position',[0.01 0.258 0.48 0.67],...
                       'BackgroundColor',colors.back);        

  //calculate normalized units to use for controls in this panel

  ctlH=0.06
  ctlW=0.18
  //Preview Button
  h.btnPreview=uicontrol(h.panelPre,'Style','pushbutton', ...
                         'String','Preview', 'Units', 'normalized', ...
                         'Position',[.72 .95 .25 .05],...
                         'Callback', "btnPreview_Callback");
  
  //Ectopic Detection
  y=0.88;dy=0.06;
  xv=0.47; xl=0.07;


  h.lblArtLocate=uicontrol(h.panelPre,'Style','text', ...
                           'String','Ectopic Detection',"fontweight","bold",...
                           'Units', 'normalized', ...
                           'HorizontalAlignment','left','BackgroundColor', colors.back,...
                           'Position',[.05 y .6 ctlH]);
  y=y-dy
  h.chkArtLocPer = uicontrol(h.panelPre,'Style','checkbox',...
                             'String','percent','Value',0,'BackgroundColor',colors.back,...
                             'Units', 'normalized',...
                             'Position',[xl y .3 ctlH]);
  h.txtArtLocPer=uicontrol(h.panelPre,'Style','edit', 'String','20',...
                           'Units', 'normalized',...
                           'HorizontalAlignment', 'center','BackgroundColor',colors.white,...
                           'Position',[xv y ctlW ctlH],...
                           'Callback', "optChange_Callback");
  h.chkArtLocSD = uicontrol(h.panelPre,'Style','checkbox',...
                            'String','std dev','Value',0,'BackgroundColor',colors.back,...
                            'Units', 'normalized',...
                            'Position',[xl y-dy .3 ctlH]);
  h.txtArtLocSD=uicontrol(h.panelPre,'Style','edit', 'String','3',...
                          'Units', 'normalized',...
                          'HorizontalAlignment', 'center','BackgroundColor',colors.white,...
                          'Position',[xv y-dy ctlW ctlH],...
                          'Callback', "optChange_Callback");
  h.chkArtLocMed = uicontrol(h.panelPre,'Style','checkbox',...
                             'String','median','Value',0,'BackgroundColor',colors.back,...
                             'Units', 'normalized',...
                             'Position',[xl y-2*dy .3 ctlH]);
  h.txtArtLocMed=uicontrol(h.panelPre,'Style','edit', 'String','4',...
                           'Units', 'normalized',...
                           'HorizontalAlignment', 'center','BackgroundColor',colors.white,...
                           'Position',[xv y-2*dy ctlW ctlH],...
                           'Callback', "optChange_Callback");
  
  //Ectopic replacment
  y=y-2*dy-ctlH;
  lblArtReplace=uicontrol(h.panelPre,'Style','text', ...
                          'String','Ectopic Replacement',"fontweight","bold",...
                          'Units', 'normalized',...
                          'HorizontalAlignment','left','BackgroundColor',colors.back,...
                          'Position',[.05 y .6 ctlH]);
  
  ctlW2=0.4
  y=y-ctlH;
  h.radioArtReplaceNone = uicontrol(h.panelPre,'Style','radiobutton', ...
                                    'String','None',"Groupname","RBTN",...
                                    'Units','normalized', 'BackgroundColor',colors.back,...
                                    'HorizontalAlignment','left',"Enable","on",...
                                    'Position',[xl y ctlW2 ctlH]);

  h.radioArtReplaceMean = uicontrol(h.panelPre,'Style','radiobutton', ...
                                    'String','Local mean',"Groupname","RBTN",...
                                    'Units','normalized', 'BackgroundColor',colors.back, ...
                                    'HorizontalAlignment','left',...
                                    'Position',[xl y-dy ctlW2 ctlH]);
  h.txtArtReplaceMean=uicontrol(h.panelPre,'Style','edit', 'String','9',...
                                'Units', 'normalized', 'HorizontalAlignment', 'center','BackgroundColor',colors.white,...
                                'Position',[xv y-dy ctlW ctlH],...
                                'Callback', "optChange_Callback");   

  h.radioArtReplaceMed = uicontrol(h.panelPre,'Style','radiobutton',...
                                   'String','Local median',"Groupname","RBTN",...
                                   'Units','normalized', 'BackgroundColor',colors.back, ...
                                   'HorizontalAlignment','left',...
                                   'Position',[xl y-2*dy ctlW2 ctlH]);
  h.txtArtReplaceMed=uicontrol(h.panelPre,'Style','edit', 'String','5',...
                               'Units', 'normalized', 'HorizontalAlignment', 'center','BackgroundColor',colors.white,...
                               'Position',[xv y-2*dy ctlW ctlH],...
                               'Callback', "optChange_Callback");  
  
  h.radioArtReplaceSpline = uicontrol(h.panelPre,'Style','radiobutton',...
                                      'String','Spline',"Groupname","RBTN",...
                                      'Units','normalized', 'BackgroundColor',colors.back, ...
                                      'HorizontalAlignment','left',...
                                      'Position',[xl y-3*dy ctlW2 ctlH]);
  h.radioArtReplaceRem = uicontrol(h.panelPre,'Style','radiobutton',...
                                   'String','Remove',"Groupname","RBTN",...
                                   'Units','normalized', 'BackgroundColor',colors.back, ...
                                   'HorizontalAlignment','left',...
                                   'Position',[xl y-4*dy .3 ctlH]);
  h.radioArtReplaceNone.value=1;
  y=y-4*dy-ctlH;
  //Detrending
  //y=0.38
  h.lblDetrend=uicontrol(h.panelPre,'Style','text', 'String','Detrending',...
                         'Units', 'normalized', 'fontweight','bold',...
                         'HorizontalAlignment','left','BackgroundColor',colors.back,...
                         'Position',[.05 y xv ctlH]);
  h.btnViewFFT=uicontrol(h.panelPre,'Style','pushbutton', ...
                         'String','View fft', 'Units', 'normalized', ...
                         'Position',[.72 y .25 .05],...
                         'Callback', "trendlineFFT");
  h.lblDetrendMethod=uicontrol(h.panelPre,'Style','text', 'String','Method :',...
                               'Units', 'normalized', ...
                               'HorizontalAlignment','left','BackgroundColor',colors.back,...
                               'Position',[xl y-dy ctlW ctlH]);
  h.listDetrend = uicontrol(h.panelPre,'Style','popupmenu',...
                            'String',['None','Wavelet','Stavisky Golay','Loess','Polynomial','Smoothness Priors'], ...
                            'Value',3,'BackgroundColor',colors.white, 'Units', 'normalized',...
                            'Position',[xv y-dy .5 ctlH],...
                            'Callback', "detrendChange_Callback");

  // Smoothing Options
  vis="off";
  y=y-dy;
  // h.lblSmoothMethod=uicontrol(h.panelPre,'Style','text', 'String','Method :',...
  //                             'Units', 'normalized', 'Visible',vis, ...
  //                             'HorizontalAlignment','left','BackgroundColor',colors.back, ...
  //                             'Position',[xl y-dy .3 ctlH]);
  
  h.lblSmoothLoessAlpha=uicontrol(h.panelPre,'Style','text', 'String','Alpha (%):',...
                                  'Units', 'normalized', 'Visible',vis, ...
                                  'HorizontalAlignment','left','BackgroundColor',colors.back, ...
                                  'Position',[xl y-dy .2 ctlH]);
  h.lblSmoothLoessOrder=uicontrol(h.panelPre,'Style','text', 'String','Degree :',...
                                  'Units', 'normalized', 'Visible',vis, ...
                                  'HorizontalAlignment','left','BackgroundColor',colors.back, ...
                                  'Position',[xl y-2*dy .2 ctlH]);
  
  h.lblSmoothSgolayLen=uicontrol(h.panelPre,'Style','text', 'String','Filter length :',...
                                 'Units', 'normalized', 'Visible',vis, ...
                                 'HorizontalAlignment','left','BackgroundColor',colors.back, ...
                                 'Position',[xl y-dy .2 ctlH]);
  h.lblSmoothSgolayDegree=uicontrol(h.panelPre,'Style','text', 'String','Degree :',...
                                    'Units', 'normalized', 'Visible',vis,...
                                    'HorizontalAlignment','left','BackgroundColor',colors.back, ...
                                    'Position',[xl y-2*dy .2 ctlH]);
  
  
  // h.listSmoothMethod = uicontrol(h.panelPre,'Style','popupmenu',...
  //                                'String',['sgolay','loess'],'Value',1,...
  //                                'BackgroundColor',colors.white,...
  //                                'Units', 'normalized', 'Visible',vis,...
  //                                'Position',[xv y-dy .27 ctlH], ...
  //                                'Callback', "detrendChange_Callback");
  
  h.txtSmoothLoessAlpha=uicontrol(h.panelPre,'Style','edit', 'String','5',...
                                  'Units', 'normalized', 'Visible',vis,...
                                  'HorizontalAlignment','center','BackgroundColor',colors.white,...
                                  'Position',[xv y-dy  ctlW ctlH],...
                                  'Callback', "optChange_Callback");
  h.txtSmoothLoessOrder=uicontrol(h.panelPre,'Style','edit', 'String','2',...
                                  'Units', 'normalized', 'Visible',vis,...
                                  'HorizontalAlignment','center','BackgroundColor',colors.white,...
                                  'Position',[xv y-2*dy ctlW ctlH],...
                                  'Callback', "optChange_Callback");
  h.txtSmoothSgolayLen=uicontrol(h.panelPre,'Style','edit', 'String','31',...
                                 'Units', 'normalized', 'Visible',vis,...
                                 'HorizontalAlignment','center','BackgroundColor',colors.white,...
                                 'Position',[xv y-dy  ctlW ctlH],...
                                 'Callback', "optChange_Callback");
  h.txtSmoothSgolayDegree=uicontrol(h.panelPre,'Style','edit', 'String','2',...
                                    'Units', 'normalized', 'Visible',vis,...
                                    'HorizontalAlignment','center','BackgroundColor',colors.white,...
                                    'Position',[xv y-2*dy ctlW ctlH],...
                                    'Callback', "optChange_Callback");

  
  //Polynomial Detrending

  vis="off";
  h.lblPoly=uicontrol(h.panelPre,'Style','text', 'String','Order :',...
                      'Units', 'normalized', 'Visible',vis,...
                      'HorizontalAlignment','left','BackgroundColor',colors.back,...
                      'Position',[xl y-dy .2 ctlH]);
  h.listPoly = uicontrol(h.panelPre,'Style','popupmenu',...
                         'visible',vis,...
                         'String',['1st Order','2nd Order','3rd Order'], ...
                         'Value',1,'BackgroundColor',colors.white, 'Units', 'normalized',...
                         'Position',[xv y-dy .35 ctlH],...
                         'Callback', "detrendChange_Callback");  
  //Wavelet Detrending Options
  vis="off"
  h.lblWaveletType=uicontrol(h.panelPre,'Style','text', 'String','Type :',...
                             'Units', 'normalized', 'Visible',vis,...
                             'HorizontalAlignment','left','BackgroundColor',colors.back,...
                             'Position',[xl y-dy .2 ctlH]);
  // h.lblWaveletType2=uicontrol(h.panelPre,'Style','text', 'String','n :',...
  //                             'Units', 'normalized', 'Visible',vis, ...
  //                             'HorizontalAlignment','left','BackgroundColor',colors.back,...
  //                             'Position',[xl y-2*dy .2 ctlH]);
  h.lblWaveletLevels=uicontrol(h.panelPre,'Style','text', 'String','Levels :',...
                               'Units', 'normalized', 'Visible',vis, ...
                               'HorizontalAlignment','left','BackgroundColor',colors.back,...
                               'Position',[xl  y-2*dy .2 ctlH]);
  h.listWaveletType = uicontrol(h.panelPre,'Style','popupmenu',...
                                'String',['db','sym','coif','leg'],'Value',1,'BackgroundColor',colors.white,...
                                'Units', 'normalized', 'Visible',vis, ...
                                'Position',[xv y-dy .27 ctlH],...
                                'Callback', "detrendChange_Callback");
  h.txtWaveletType2=uicontrol(h.panelPre,'Style','edit', 'String','3',...
                              'Units', 'normalized', 'Visible',vis, ...
                              'HorizontalAlignment','center','BackgroundColor',colors.white,...
                              'Position',[xv+0.3 y-dy ctlW ctlH],...
                              'Callback', "optChange_Callback");
  h.txtWaveletLevels=uicontrol(h.panelPre,'Style','edit', 'String','6',...
                               'Units', 'normalized', 'Visible',vis, ...
                               'HorizontalAlignment','center','BackgroundColor',colors.white,...
                               'Position',[xv y-2*dy ctlW ctlH],...
                               'Callback', "optChange_Callback");
  
  //Smoothness Priors
  vis="off";
  h.lblPriorsFc=uicontrol(h.panelPre,'Style','text', 'String','fc :',...
                              'Units', 'normalized', 'Visible',vis, ...
                              'HorizontalAlignment','left','BackgroundColor',colors.back,...
                              'Position',[xl y-dy .2 ctlH]);
  h.txtPriorsFc = uicontrol(h.panelPre,'Style','edit',...
                                'String','0.01','BackgroundColor',colors.white, ...
                                'Units', 'normalized', 'Visible',vis, ...
                                'Position',[xv y-dy  ctlW ctlH],...
                                'Callback', "detrendChange_Callback");
  
  
  //// GUI: Analysis Options - Time Domain---------------------------------------------------------

  h.panelOptTime = uipanel('Parent',h.panelOptions,'title','Time Domain',...
                           'Units', 'normalized', 'Position',[.01 .01 .235 .242],...
                           'FontWeight','bold', 'BackgroundColor',colors.back);
  
  
  x1=0.4;x2=x1+.25+.05; 
  
  ctlH=0.17;dy=ctlH
  y=0.6;
 
  
  h.lblPNNx=uicontrol(h.panelOptTime,'Style','text', 'String','pNNx :',...
                      'Units', 'normalized', 'Position',[.05 y .35 ctlH],...
                      'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.txtPNNx=uicontrol(h.panelOptTime,'Style','edit', 'String','50',...
                      'Units', 'normalized', 'Position',[x1 y .25 ctlH],...
                      'HorizontalAlignment','center','BackgroundColor',colors.white,...
                      'Callback', "optChange_Callback");
  uicontrol(h.panelOptTime,'Style','text', 'String','(ms)',...
            'Units', 'normalized', 'Position',[x2 y .2 ctlH],...
            'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.lblSDNNi=uicontrol(h.panelOptTime,'Style','text', 'String','SDNNi :',...
                       'Units', 'normalized', 'Position',[.05 y-dy .35 ctlH],...
                       'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.txtSDNNi=uicontrol(h.panelOptTime,'Style','edit', 'String','1',...
                       'Units', 'normalized', 'Position',[x1 y-dy .25 ctlH],...
                       'HorizontalAlignment','center','BackgroundColor',colors.white,...
                       'Callback', "optChange_Callback");
  uicontrol(h.panelOptTime,'Style','text', 'String','(min)',...
            'Units', 'normalized', 'Position',[x2 y-dy .25 ctlH],...
            'HorizontalAlignment','left', 'BackgroundColor',colors.back);    
  
  //// GUI: Analysis Options - Freq Domain---------------------------------------------------------
  
  h.panelOptFreq = uipanel('Parent',h.panelOptions,'title','Freq Domain',...
                           'Units', 'normalized', 'Position',[.51 0.258 .48 .67],...
                           'FontWeight','bold', 'BackgroundColor',colors.back);
  
  //calculate normalized units to use for controls in this panel
  ctlH=0.0656
  ctlW=0.1875
  // Bands
  h.lblBands=uicontrol(h.panelOptFreq,'Style','text', 'String','Frequency Bands',...
                       'Units', 'normalized', ...
                       'HorizontalAlignment','left','BackgroundColor',colors.back,'fontweight','bold',..
                       'Position',[.05 .88 .5 ctlH]);
  y=0.82;dy=0.09;
  
  //Very low frequency band
  h.lblVLF=uicontrol(h.panelOptFreq,'Style','text', 'String','VLF (Hz) :',...
                     'Units', 'normalized', ...
                     'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                     'Position',[.07 y .3 ctlH]);
  h.txtVLF1=uicontrol(h.panelOptFreq,'Style','edit', 'String','0',...
                      'Units', 'normalized', ...
                      'HorizontalAlignment','center','BackgroundColor',colors.vlf,...
                      'user_data',colors.vlf,...
                      'Position',[.35 y ctlW ctlH],...
                      'Callback', "optChange_Callback");    
  h.txtVLF2=uicontrol(h.panelOptFreq,'Style','edit', 'String','0.04',...
                      'Units', 'normalized',...
                      'HorizontalAlignment','center','BackgroundColor',colors.vlf,...
                      'user_data',colors.vlf,...
                      'Position',[.6 y ctlW ctlH],...
                      'Callback', "optChange_Callback");
  h.lblVLFHyph=uicontrol(h.panelOptFreq,'Style','text', 'String','-',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','center','BackgroundColor',colors.back,...
                         'Position',[.35+ctlW y .6-.35-ctlW ctlH]);  
  
  //Low frequency band
  h.lblLF=uicontrol(h.panelOptFreq,'Style','text', 'String','LF (Hz) :',...
                    'Units', 'normalized', ...
                    'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                    'Position',[.07 y-dy .3 ctlH]);
  h.txtLF1=uicontrol(h.panelOptFreq,'Style','edit', 'String','0.04',...
                     'Units', 'normalized',...
                     'HorizontalAlignment','center','BackgroundColor',colors.lf, ...
                     'user_data',colors.lf,...
                     'Position',[.35 y-dy ctlW ctlH]);    
  h.txtLF2=uicontrol(h.panelOptFreq,'Style','edit', 'String','0.15',...
                     'Units', 'normalized', 'Tag','OptFreq txtLF', ...
                     'HorizontalAlignment','center','BackgroundColor',colors.lf,...
                     'user_data',colors.vlf,...
                     'Position',[.6 y-dy ctlW ctlH],...
                     'Callback', "optChange_Callback");
  h.lblLFhyph=uicontrol(h.panelOptFreq,'Style','text', 'String','-',...
                        'Units', 'normalized',...
                        'HorizontalAlignment','center','BackgroundColor',colors.back,...
                        'Position',[.35+ctlW y-dy .6-.35-ctlW ctlH]); 
  
  //High frequency band
  h.lblHF=uicontrol(h.panelOptFreq,'Style','text', 'String','HF (Hz) :',...
                    'Units', 'normalized',...
                    'HorizontalAlignment','left', 'BackgroundColor',colors.back, ...
                    'Position',[.07 y-2*dy .3 ctlH], ...
                    'Callback', "optChange_Callback");    
  h.txtHF1=uicontrol(h.panelOptFreq,'Style','edit', 'String','0.15',...
                     'Units', 'normalized',...
                     'HorizontalAlignment','center','BackgroundColor',colors.hf,...
                     'user_data',colors.hf,...
                     'Position',[.35 y-2*dy ctlW ctlH],...
                     'Callback', "optChange_Callback");    
  h.txtHF2=uicontrol(h.panelOptFreq,'Style','edit', 'String','0.4',...
                     'Units', 'normalized',  ...
                     'HorizontalAlignment','center','BackgroundColor',colors.hf,...
                     'user_data',colors.hf,...
                     'Position',[.6 y-2*dy ctlW ctlH],...
                     'Callback', "optChange_Callback");
  h.lblHFhyph=uicontrol(h.panelOptFreq,'Style','text', 'String','-',...
                        'Units', 'normalized', ...
                        'HorizontalAlignment','center','BackgroundColor',colors.back,...
                        'Position',[.35+ctlW y-2*dy .6-.35-ctlW ctlH]); 
  
  //Interpolation
  h.lblInterp1=uicontrol(h.panelOptFreq,'Style','text', ...
                         'String','IBI Interpolation',...
                         'Units', 'normalized', 'fontweight', 'bold',...
                         'HorizontalAlignment','left', 'BackgroundColor',colors.back, ...
                         'Position',[.05 .52 .6 ctlH]);
  y=0.45;dy=0.06;lblW=0.5;
  h.lblInterp=uicontrol(h.panelOptFreq,'Style','text', ...
                        'String','Interpolation Rate (Hz) :',...
                        'Units', 'normalized', ...
                        'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                        'Position',[.07 y lblW ctlH]);     
  h.txtInterp=uicontrol(h.panelOptFreq,'Style','edit', 'String','2',...
                        'Units', 'normalized', ...
                        'HorizontalAlignment','center','BackgroundColor',colors.white,...
                        'Position',[.6 y ctlW ctlH],...
                        'Callback', "optChange_Callback");
  
  //Points in calculated PSD
  h.lblPnts=uicontrol(h.panelOptFreq,'Style','text', 'String','Points in PSD',...
                      'Units', 'normalized', ...
                      'HorizontalAlignment','left', 'BackgroundColor',colors.back,'fontweight', 'bold',...
                      'Position',[.05 y-dy lblW ctlH]);
  h.lblPoints=uicontrol(h.panelOptFreq,'Style','text',...
                        'String','Points in PSD (pts) :',...
                        'Units', 'normalized', ...
                        'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                        'Position',[.07 y-2*dy lblW ctlH]);  
  h.txtPoints=uicontrol(h.panelOptFreq,'Style','edit', 'String','512',...
                        'Units', 'normalized',..
                        'HorizontalAlignment','center','BackgroundColor',colors.white,...
                        'Position',[.6 y-2*dy ctlW ctlH],...
                        'Callback', "optChange_Callback");
  
  //Welch Windowing
  h.lblWelch=uicontrol(h.panelOptFreq,'Style','text', 'String','Welch Options',...
                       'Units', 'normalized', ...
                       'HorizontalAlignment','left', 'BackgroundColor',colors.back,'fontweight', 'bold',...
                       'Position',[.05 y-3*dy lblW ctlH]);
  h.lblWinWidth=uicontrol(h.panelOptFreq,'Style','text',...
                          'String','Window Width (pts) :',...
                          'Units', 'normalized', ...
                          'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                          'Position',[.07 y-4*dy lblW ctlH]);
  h.txtWinWidth=uicontrol(h.panelOptFreq,'Style','edit', 'String','128',...
                          'Units', 'normalized', ...
                          'HorizontalAlignment','center','BackgroundColor',colors.white,...
                          'Position',[.6 y-4*dy ctlW ctlH],...
                          'Callback', "optChange_Callback");
  h.lblWinOverlap=uicontrol(h.panelOptFreq,'Style','text',...
                            'String','Window Overlap (pts) :',...
                            'Units', 'normalized',  ...
                            'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                            'Position',[.07 y-5*dy lblW ctlH]); 
  h.txtWinOverlap=uicontrol(h.panelOptFreq,'Style','edit',...
                            'String','64',...
                            'Units', 'normalized', ...
                            'HorizontalAlignment','center', 'BackgroundColor',colors.white,...
                            'Position',[.6 y-5*dy ctlW ctlH]); 
  
  //Burg AR Model
  h.lblAROrder=uicontrol(h.panelOptFreq,'Style','text', 'String','AR Burg Options',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','left', 'BackgroundColor',colors.back,'fontweight', 'bold',...
                         'Position',[.05 y-6*dy lblW ctlH]);
  h.lblAROrder=uicontrol(h.panelOptFreq,'Style','text',...
                         'String','Model Order :',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                         'Position',[.07 y-7*dy lblW ctlH]);   
  h.txtAROrder=uicontrol(h.panelOptFreq,'Style','edit', 'String','16',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','center','BackgroundColor',colors.white,...
                         'Position',[.6 y-7*dy ctlW ctlH],...
                         'Callback', "optChange_Callback");
  

  //// GUI: Analysis Options - Nonlinear---------------------------------------------------------

  h.panelOptNL = uipanel('Parent',h.panelOptions,'title','Nonlinear',...
                         'Units', 'normalized', 'Position',[.51 .01 .48 .25],...
                         'FontWeight','bold', 'BackgroundColor',colors.back);
  
  //calculate normalized units to use for controls in this panel

  ctlW=0.1875 
  ctlH=0.165
  y=0.7
  //SampEn
  h.lblSampEn=uicontrol(h.panelOptNL,'Style','text', 'String','Sample Entropy',...
                        'Units', 'normalized', 'fontweight','bold',...
                        'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                        'Position',[.05 y .9 ctlH]);
  h.lblSampEnR=uicontrol(h.panelOptNL,'Style','text', 'String','r :',...
                         'Units', 'normalized',...
                         'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                         'Position',[.07 y-ctlH .1 ctlH]);
  h.txtSampEnR=uicontrol(h.panelOptNL,'Style','edit', 'String','0.1',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','center','BackgroundColor',colors.white,...
                         'Position',[.07+.1 y-ctlH ctlW ctlH],...
                         'Callback', "optChange_Callback");
  h.lblSampEnM=uicontrol(h.panelOptNL,'Style','text', 'String','m :',...
                         'Units', 'normalized',...
                         'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                         'Position',[.6-.1 y-ctlH .1 ctlH]);
  h.txtSampEnM=uicontrol(h.panelOptNL,'Style','edit', 'String','3',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','center','BackgroundColor',colors.white,...
                         'Position',[.6 y-ctlH ctlW ctlH],...
                         'Callback', "optChange_Callback");
  //DFA
  h.lblDFA=uicontrol(h.panelOptNL,'Style','text', 'String','Detrended Fluctuation Analysis',...
                     'Units', 'normalized',  'fontweight','bold',...
                     'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                     'Position',[.05 y-2*ctlH .9 ctlH]);
  
  h.lblDFAn=uicontrol(h.panelOptNL,'Style','text', 'String','n range:',...
                      'Units', 'normalized',...
                      'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                      'Position',[.07 y-3*ctlH .25 ctlH]);
  h.txtDFAn1=uicontrol(h.panelOptNL,'Style','edit', 'String','4',...
                       'Units', 'normalized',...
                       'HorizontalAlignment','center','BackgroundColor',colors.white,...
                       'Position',[.35 y-3*ctlH ctlW ctlH],...
                       'Callback', "optChange_Callback");
  h.txtDFAn2=uicontrol(h.panelOptNL,'Style','edit', 'String','100',...
                       'Units', 'normalized',...
                       'HorizontalAlignment','center','BackgroundColor',colors.white,...
                       'Position',[.6 y-3*ctlH ctlW ctlH],...
                       'Callback', "optChange_Callback");
  h.lblDFAhyph=uicontrol(h.panelOptNL,'Style','text', 'String','-',...
                         'Units', 'normalized', ...
                         'HorizontalAlignment','center','BackgroundColor',colors.back,...
                         'Position',[.35+ctlW y-3*ctlH 0.6-0.35-ctlW ctlH]); 
  
  h.lblDFAbp=uicontrol(h.panelOptNL,'Style','text', 'String','Break Point :',...
                       'Units', 'normalized',...
                       'HorizontalAlignment','left', 'BackgroundColor',colors.back,...
                       'Position',[.07 y-4*ctlH  .3 ctlH]);
  h.txtDFAbp=uicontrol(h.panelOptNL,'Style','edit', 'String','13',...
                       'Units', 'normalized', ...
                       'HorizontalAlignment','center','BackgroundColor',colors.white,...
                       'Position',[.6 y-4*ctlH  ctlW ctlH],...
                       'Callback', "optChange_Callback");

  //// GUI: Analysis Options - TimeFreq
  h.panelOptTimeFreq = uipanel('Parent',h.panelOptions,'title','Time-Freq',...
                               'Units', 'normalized', 'Position',[.255 .01 .235 .242],...
                               'FontWeight','bold', 'BackgroundColor',colors.back);
  
 
  ctlW=0.383;
  ctlH=0.17;
  y=0.8;
  xl=0.05;
  xv=0.47;
  xu=.82;
  h.lblTFwinSize=uicontrol(h.panelOptTimeFreq,'Style','text', 'String','Window :',...
                           'Units', 'normalized', 'Position',[xl y-ctlH .42 ctlH],...
                           'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.txtTFwinSize=uicontrol(h.panelOptTimeFreq,'Style','edit', 'String','30',...
                           'Units', 'normalized', 'Position',[xv y-ctlH .35 ctlH],...
                           'HorizontalAlignment','center','BackgroundColor',colors.white,...
                           'Callback', "optChange_Callback");
  uicontrol(h.panelOptTimeFreq,'Style','text', 'String','(s)',...
            'Units', 'normalized', 'Position',[xu y-ctlH .15 ctlH],...
            'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  
  h.lblTFoverlap=uicontrol(h.panelOptTimeFreq,'Style','text', 'String','Overlap :',...
                           'Units', 'normalized', 'Position',[xl y-2*ctlH .42 ctlH],...
                           'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.txtTFoverlap=uicontrol(h.panelOptTimeFreq,'Style','edit', 'String','15',...
                           'Units', 'normalized', 'Position',[xv y-2*ctlH .35 ctlH],...
                           'HorizontalAlignment','center','BackgroundColor',colors.white,...
                           'Callback', "optChange_Callback");    
  uicontrol(h.panelOptTimeFreq,'Style','text', 'String','(s)',...
            'Units', 'normalized', 'Position',[xu y-2*ctlH .15 ctlH],...
            'HorizontalAlignment','left', 'BackgroundColor',colors.back); 

  h.lblTFTimeSmooth=uicontrol(h.panelOptTimeFreq,'Style','text', 'String','TSW',...
                           'Units', 'normalized', 'Position',[xl y-3*ctlH .42 ctlH],...
                           'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.txtTFTimeSmooth=uicontrol(h.panelOptTimeFreq,'Style','edit', 'String','5',...
                           'Units', 'normalized', 'Position',[xv y-3*ctlH .35 ctlH],...
                           'HorizontalAlignment','center','BackgroundColor',colors.white,...
                           'Callback', "optChange_Callback"); 
  uicontrol(h.panelOptTimeFreq,'Style','text', 'String','(%)',...
            'Units', 'normalized', 'Position',[xu y-3*ctlH .15 ctlH],...
            'HorizontalAlignment','left', 'BackgroundColor',colors.back); 
  h.lblTFFreqSmooth=uicontrol(h.panelOptTimeFreq,'Style','text', 'String','FSW',...
                           'Units', 'normalized', 'Position',[xl y-4*ctlH .42 ctlH],...
                           'HorizontalAlignment','left', 'BackgroundColor',colors.back);
  h.txtTFFreqSmooth=uicontrol(h.panelOptTimeFreq,'Style','edit', 'String','15',...
                           'Units', 'normalized', 'Position',[xv y-4*ctlH .35 ctlH],...
                           'HorizontalAlignment','center','BackgroundColor',colors.white,...
                           'Callback', "optChange_Callback");    
  uicontrol(h.panelOptTimeFreq,'Style','text', 'String','(%)',...
            'Units', 'normalized', 'Position',[xu y-4*ctlH .15 ctlH],...
            'HorizontalAlignment','left', 'BackgroundColor',colors.back); 
  ////  GUI: Results - Tab Group---------------------------------------------------------
  //Options panel
  h.tabgroup = uicontrol('Parent',MainFigure, "style", "tab",...
                         'Units','normalized','Position',[.5 0 .5 .7],...
                         "tag" ,"tabs", "constraints", createConstraints("border", "center"));

  //// GUI: Results - Time Domain Tab---------------------------------------------------------
  c=createConstraints("nolayout");
  h.tab1 = uipanel('Parent',h.tabgroup, 'string', 'Time Domain','layout',"border");
  c=createConstraints("nolayout");
  h.panelTime = uipanel('Parent',h.tab1,'BackgroundColor', colors.white);
  t1=uicontrol("parent",h.panelTime,"style","frame","units","normalized",...
               "position",[0 0 1 0.04],'BackgroundColor',colors.back);
  t2=uicontrol("parent",h.panelTime,"style","frame","units","normalized",...
               "position",[0 0.04 1 0.41],'BackgroundColor',colors.back);
  t3=uicontrol("parent",h.panelTime,"style","frame","units","normalized",...
               "position",[0 0.45 1 1-0.45],'BackgroundColor',colors.back);

  h.axesHistIBI=uiaxes('parent', t2,'Position',[0.06 0.15 0.41 0.63],'Box','on');
  axesHistIBI.fractional_font="on";axesHistIBI.font_size=0.6;
  xlabel(h.axesHistIBI,'IBI (ms)'); title(h.axesHistIBI,'IBI Histogram')

  
  b1=uicontrol(t1,'Style','pushbutton', 'String','^', 'Units','normalized',...
               'Position',[0.01 0 0.04,1],"callback","graph_open(""axesHistIBI"")");

  b2=uicontrol(t1,'Style','pushbutton', 'String','^', 'Units','normalized',...
               'Position',[0.54 0 0.04,1],"callback","graph_open(""axesHistBPM"")");

  h.axesHistBPM=uiaxes('parent', t2,'Position',[0.55 0.15 0.41 0.63],'Box','on');
  axesHistBPM.fractional_font="on";axesHistBPM.font_size=0.6;
  xlabel(h.axesHistBPM,'HR (bpm)'); title(h.axesHistBPM,'HR Histogram')
  
  h.axesTimeTbl = uiaxes('parent', t3,'Position',[0 0 1 1],'FontSize',7,'Box','on');
  h.axesTimeTbl.axes_visible="off";

  //create Table for Time Domain Results and return handles of text objects
  h.text.time = createTimeTbl(h.axesTimeTbl);    
  
  //// GUI: Results - Freq Domain Tab---------------------------------------------------------
  h.tab2 = uipanel('Parent',h.tabgroup, 'string', 'Freq Domain','layout',"border");
  h.panelFreq = uipanel('Parent',h.tab2,'Position',[0 0 1 1],...
                        'BackgroundColor',colors.white);
  h.FreqPlot= uicontrol('parent', h.panelFreq,'style','frame','Units', ...
                        'normalized','Position',[0 0.5 1 0.44]);
  h.axesFreq = uiaxes('parent', h.FreqPlot,'Position',[0.15 .07 .8 .7],...
                      'FontSize',7,'Box','on');
  xlabel(h.axesFreq, 'Freq (Hz)'); ylabel(h.axesFreq, 'PSD (ms^2/Hz)');
  h.FreqTbl=uicontrol('parent', h.panelFreq,'style','frame','Units', ...
                      'normalized','Position',[0 0.0 1 0.50], ...
                      'BackgroundColor',colors.white);
  h.axesFreqTbl = uiaxes('parent', h.FreqTbl,'Position',[0 0 1 1]);
  h.axesFreqTbl.axes_visible="off";
  //create Table for Freq Domain Results and return handles of text
  //objects
  h.text.freq = createFreqTbl(h.axesFreqTbl);
 
  // Create the button group.
  h.btngrpFreqPlot = uipanel('parent', h.panelFreq,'Units', ...
                             'normalized','Position',[0 0.94 1 0.06], ...
                             'BackgroundColor',colors.back);
  y=0.1;H=0.75;
  h.lblFreqPlot = uicontrol(h.btngrpFreqPlot,'Style','text','String','Method:',...
                            'Units','normalized', 'Position',[.005 y .1 H],'BackgroundColor',colors.back,...
                            'HorizontalAlignment','left');
  h.radioFreqPlotW = uicontrol(h.btngrpFreqPlot,'Style','radiobutton', ...
                               "Groupname","RBTNF",...                       
                               'String','Welch',...
                               'Units','normalized', 'Position',[.1 y .15 H],'BackgroundColor',colors.back,...
                               'HorizontalAlignment','left','callback',"freqPlotChange_Callback(""Welch"")");
  h.radioFreqPlotAR = uicontrol(h.btngrpFreqPlot,'Style','radiobutton', ...
                                "Groupname","RBTNF",...                       
                                'String','Burg',...
                                'Units','normalized', 'Position',[.25 y .15 H],'BackgroundColor',colors.back,...
                                'HorizontalAlignment','left','callback',"freqPlotChange_Callback(""Burg"")");
  h.radioFreqPlotLS = uicontrol(h.btngrpFreqPlot,'Style','radiobutton', ...
                                "Groupname","RBTNF",...                       
                                'String','LombScargle',...
                                'Units','normalized', 'Position',[.4 y 0.25 H],'BackgroundColor',colors.back,...
                                'HorizontalAlignment','left','callback',"freqPlotChange_Callback(""LS"")");
  h.radioFreqPlotLS.value=1;
  b=uicontrol(h.btngrpFreqPlot,'Style','pushbutton', 'String','^', 'Units','normalized',...
              'Position',[0.95 0 0.04 0.8],"callback","graph_open(""axesFreq"")");

  //// GUI: Results - Poincare Tab---------------------------------------------------------
  h.tab3 = uipanel('Parent',h.tabgroup, 'string', 'Poincare','layout',"border");
  h.panelPoincare = uipanel('Parent',h.tab3,'BackgroundColor',colors.back); 
  t1=uicontrol("parent",h.panelPoincare,"style","frame","units","normalized",...
               "position",[0 0 1 0.04],'BackgroundColor',colors.back);
  b=uicontrol(t1,'Style','pushbutton', 'String','^', 'Units','normalized',...
              'Position',[0.02 0 0.04 1],"callback","graph_open(""axesPoincare"")");

  t2=uicontrol("parent",h.panelPoincare,"style","frame","units","normalized",...
               "position",[0 0.06 1 1-0.06],'BackgroundColor',colors.back);
  

  h.axesPoincare = uiaxes('parent', t2,'Position',[.1 .1 .85 .85], ...
                          'FontSize',7,'Box','on');        
  //// GUI: Results - Nonlinear Tab---------------------------------------------------------
  h.tab4 = uipanel('Parent',h.tabgroup, 'string', 'NonlineaR','layout',"border");
  h.panelNL = uipanel('Parent',h.tab4,'BackgroundColor',colors.back); 
  
  t1=uicontrol("parent",h.panelNL,"style","frame","units","normalized",...
               "position",[0.01 0.45 0.04 0.04],'BackgroundColor',colors.back);

  t2=uicontrol("parent",h.panelNL,"style","frame","units","normalized",...
               "position",[0 0.49 1 1-0.49],'BackgroundColor',colors.back);
  t3=uicontrol("parent",h.panelNL,"style","frame","units","normalized",...
               "position",[0 0 1 0.45],'BackgroundColor',colors.back);
  
  b=uicontrol(t1,'Style','pushbutton', 'String','^', 'Units','normalized',...
              'Position',[0 0 1 1],"callback","graph_open(""axesNL"")");
  
  h.axesNL = uiaxes('parent', t2,'Position',[.1 .06 .85 .7], ...
                    'FontSize',8,'Box','on');
  title(h.axesNL,'DFA')
  xlabel(h.axesNL,'log_1_0 n')
  ylabel(h.axesNL,'log_1_0 F(n)')    
  h.axesNLTbl = uiaxes('parent', t3,'Position',[0 0 1 1]);
  h.axesNLTbl.axes_visible="off";
  //create Table for nonlinear Results and return handles of text objects
  h.text.nl = createNLTbl(h.axesNLTbl); 
  //// GUI: Results - TimeFreq Tab---------------------------------------------------------
  h.tab6 = uipanel('Parent',h.tabgroup, 'String', 'Time-Freq','layout',"border");
  h.panelTF = uicontrol('Parent',h.tab6,'style','frame','Position',[.0 .0 1 1],...
                        'BackgroundColor',colors.back);

  

  h.TFPlot= uicontrol('parent', h.panelTF,'style','frame','Units', ...
                      'normalized','Position',[0 0.48 1 0.45]);
  h.axesTF = uiaxes('parent', h.TFPlot,'Position',[.15 .07 .8 .7], ...
                    'FontSize',7,'Box','on');
  //colorbar
  h.axesTFCB = uiaxes('parent', h.TFPlot,'Position',[.89 .07 .02 .7],'FontSize',7,'Box','on');
  h.axesTFCB.visible="off"
  h.axesTFCB.y_location = "right";
  h.axesTFCB.tight_limits ="on";
  h.axesTFCB.auto_ticks = ["off","on","off"];
  h.axesTFCB.ticks_format(2)="%.0f"
  h.axesTFCB.sub_ticks(2)=0;
  h.axesTFCB.x_ticks=tlist(["ticks","locations","labels"],[],[]);
  
  h.TFTbl= uicontrol('parent', h.panelTF,'style','frame','Units', ...
                     'normalized','Position',[0 0 1 0.475], ...
                     'BackgroundColor',[1 0 0]);
  

  //create Table for Freq Domain Results and return handles of text  objects
  h.axesTFTbl=uiaxes('parent', h.TFTbl,'Position',[0 0 1 1],'FontSize', ...
                     7,'Box','on');
  h.text.tf = createTFTbl(h.axesTFTbl); 
  // Create Method button group.
  h.btngrpTFPlot=uipanel('parent', h.panelTF,'Units', ...
                         'normalized','Position',[0 .94 1 0.06], ...
                         'BackgroundColor',colors.back);
  y=0.1;H=0.75;

  h.lblTFMeth = uicontrol(h.btngrpTFPlot,'Style','text','String','PSD Method:',...
                          'Units','normalized', 'Position',[.005 y .17 H],'BackgroundColor',colors.back,...
                          'HorizontalAlignment','left');
  
  h.listTFMeth = uicontrol(h.btngrpTFPlot,'Style','popupmenu',...
                           'String',['Burg', 'LombScargle','SPWV','Wavelet'],...
                           'Tag','TFMeth',...
                           'Value',3,'BackgroundColor',colors.white,...
                           'Units', 'normalized', 'Position',[.2 y .2 H],...
                           'Callback', "TFPlotChange_Callback");
   if %f
  h.radioTFPlotAR = uicontrol(h.btngrpTFPlot,'Style','radiobutton', ...
                              "Groupname","RBTN1",...                       
                              'String','Burg',...
                              'Units','normalized', 'Position',[.15 y .15 H],'BackgroundColor',colors.back,...
                              'HorizontalAlignment','left','callback',"TFPlotChange_Callback(""Burg"")");
  h.radioTFPlotLS =uicontrol(h.btngrpTFPlot,'Style','radiobutton',...
                             "Groupname","RBTN1",... 
                             "value",1,...
                             'String','LombScargle',...
                             'Units','normalized', 'Position',[.3 y .2 H],'BackgroundColor',colors.back,...
                             'HorizontalAlignment','left','callback',"TFPlotChange_Callback(""LS"")");
  h.radioTFPlotWav = uicontrol(h.btngrpTFPlot,'Style','radiobutton',...
                               "Groupname","RBTN1",... 
                               'String','Wavelet',...
                               'Units','normalized', 'Position',[.5 y 0.15 H],'BackgroundColor',colors.back,...
                               'HorizontalAlignment','left','callback',"TFPlotChange_Callback(""Wavelet"")");
  end
  //add button for plot export
  b=uicontrol(h.btngrpTFPlot,'Style','pushbutton', 'String','^', 'Units','normalized',...
              'Position',[0.95 0 0.04 0.8],"callback","graph_open(""axesTF"")");

  // Create Type button group.
  h.listTFPlot = uicontrol(h.btngrpTFPlot,'Style','popupmenu',...
                           'String',['Spectrogram', 'Spectrogram (log)','Surface',...//'Waterfall', ...
                    'Global PSD','LF/HF Ratio','LF & HF Power'], ...
                           'Tag','TFPlot',...
                           'Value',1,'BackgroundColor',colors.white,...
                           'Units', 'normalized', 'Position',[.7 y .2 H],...
                           'Callback', "TFPlotChange_Callback");
  h.lblStatus=createStatus(MainFigure);
endfunction
